==> xlniuxdata-vipgame-1.0.65-20160825.060954-49-sources.jar: com/xunlei/niux/data/vipgame/dto/CheatingReportDTO.java <==
package com.xunlei.niux.data.vipgame.dto;

/**
 * Created by zy on 2016/1/13.
 */
public class CheatingReportDTO {

    private Long seqid;
    private String  providerGameId;
    private String  providerServerId;
    private String  providerRoleName;
    private String  providerUserId;
    private String  reportTime;
    private String  cheaterGameId;
    private String  cheaterServerId;
    private String  cheaterRoleName;
    private String  cheaterCustomerId;
    private String  timeOfCheating;
    private String  descOfCheating;
    private String  videoOfCheating;
    private String  urlOfCheating;
    private String  handler;
    private String  handleTime;
    private String  handleDesc;
    private Integer  status;
    private Long  lockSeconds;

    private String startTime;
    private String endTime;

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public String getProviderGameId() {
        return providerGameId;
    }

    public void setProviderGameId(String providerGameId) {
        this.providerGameId = providerGameId;
    }

    public String getProviderServerId() {
        return providerServerId;
    }

    public void setProviderServerId(String providerServerId) {
        this.providerServerId = providerServerId;
    }

    public String getProviderRoleName() {
        return providerRoleName;
    }

    public void setProviderRoleName(String providerRoleName) {
        this.providerRoleName = providerRoleName;
    }

    public String getProviderUserId() {
        return providerUserId;
    }

    public void setProviderUserId(String providerUserId) {
        this.providerUserId = providerUserId;
    }

    public String getReportTime() {
        return reportTime;
    }

    public void setReportTime(String reportTime) {
        this.reportTime = reportTime;
    }

    public String getCheaterGameId() {
        return cheaterGameId;
    }

    public void setCheaterGameId(String cheaterGameId) {
        this.cheaterGameId = cheaterGameId;
    }

    public String getCheaterServerId() {
        return cheaterServerId;
    }

    public void setCheaterServerId(String cheaterServerId) {
        this.cheaterServerId = cheaterServerId;
    }

    public String getCheaterRoleName() {
        return cheaterRoleName;
    }

    public void setCheaterRoleName(String cheaterRoleName) {
        this.cheaterRoleName = cheaterRoleName;
    }

    public String getCheaterCustomerId() {
        return cheaterCustomerId;
    }

    public void setCheaterCustomerId(String cheaterCustomerId) {
        this.cheaterCustomerId = cheaterCustomerId;
    }

    public String getTimeOfCheating() {
        return timeOfCheating;
    }

    public void setTimeOfCheating(String timeOfCheating) {
        this.timeOfCheating = timeOfCheating;
    }

    public String getDescOfCheating() {
        return descOfCheating;
    }

    public void setDescOfCheating(String descOfCheating) {
        this.descOfCheating = descOfCheating;
    }

    public String getVideoOfCheating() {
        return videoOfCheating;
    }

    public void setVideoOfCheating(String videoOfCheating) {
        this.videoOfCheating = videoOfCheating;
    }

    public String getUrlOfCheating() {
        return urlOfCheating;
    }

    public void setUrlOfCheating(String urlOfCheating) {
        this.urlOfCheating = urlOfCheating;
    }

    public String getHandler() {
        return handler;
    }

    public void setHandler(String handler) {
        this.handler = handler;
    }

    public String getHandleTime() {
        return handleTime;
    }

    public void setHandleTime(String handleTime) {
        this.handleTime = handleTime;
    }

    public String getHandleDesc() {
        return handleDesc;
    }

    public void setHandleDesc(String handleDesc) {
        this.handleDesc = handleDesc;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Long getLockSeconds() {
        return lockSeconds;
    }

    public void setLockSeconds(Long lockSeconds) {
        this.lockSeconds = lockSeconds;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }
}

==> xlniuxdata-vipgame-1.1.5-20190424.035512-4-sources.jar: com/xunlei/niux/data/vipgame/dto/CheatingReportDTO.java <==
package com.xunlei.niux.data.vipgame.dto;

/**
 * Created by zy on 2016/1/13.
 */
public class CheatingReportDTO {

    private Long seqid;
    private String  providerGameId;
    private String  providerServerId;
    private String  providerRoleName;
    private String  providerUserId;
    private String  reportTime;
    private String  cheaterGameId;
    private String  cheaterServerId;
    private String  cheaterRoleName;
    private String  cheaterCustomerId;
    private String  timeOfCheating;
    private String  descOfCheating;
    private String  videoOfCheating;
    private String  urlOfCheating;
    private String  handler;
    private String  handleTime;
    private String  handleDesc;
    private Integer  status;
    private Long  lockSeconds;
    private Integer cheaterType;

    private String startTime;
    private String endTime;

    public Integer getCheaterType() {
        return cheaterType;
    }

    public void setCheaterType(Integer cheaterType) {
        this.cheaterType = cheaterType;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public String getProviderGameId() {
        return providerGameId;
    }

    public void setProviderGameId(String providerGameId) {
        this.providerGameId = providerGameId;
    }

    public String getProviderServerId() {
        return providerServerId;
    }

    public void setProviderServerId(String providerServerId) {
        this.providerServerId = providerServerId;
    }

    public String getProviderRoleName() {
        return providerRoleName;
    }

    public void setProviderRoleName(String providerRoleName) {
        this.providerRoleName = providerRoleName;
    }

    public String getProviderUserId() {
        return providerUserId;
    }

    public void setProviderUserId(String providerUserId) {
        this.providerUserId = providerUserId;
    }

    public String getReportTime() {
        return reportTime;
    }

    public void setReportTime(String reportTime) {
        this.reportTime = reportTime;
    }

    public String getCheaterGameId() {
        return cheaterGameId;
    }

    public void setCheaterGameId(String cheaterGameId) {
        this.cheaterGameId = cheaterGameId;
    }

    public String getCheaterServerId() {
        return cheaterServerId;
    }

    public void setCheaterServerId(String cheaterServerId) {
        this.cheaterServerId = cheaterServerId;
    }

    public String getCheaterRoleName() {
        return cheaterRoleName;
    }

    public void setCheaterRoleName(String cheaterRoleName) {
        this.cheaterRoleName = cheaterRoleName;
    }

    public String getCheaterCustomerId() {
        return cheaterCustomerId;
    }

    public void setCheaterCustomerId(String cheaterCustomerId) {
        this.cheaterCustomerId = cheaterCustomerId;
    }

    public String getTimeOfCheating() {
        return timeOfCheating;
    }

    public void setTimeOfCheating(String timeOfCheating) {
        this.timeOfCheating = timeOfCheating;
    }

    public String getDescOfCheating() {
        return descOfCheating;
    }

    public void setDescOfCheating(String descOfCheating) {
        this.descOfCheating = descOfCheating;
    }

    public String getVideoOfCheating() {
        return videoOfCheating;
    }

    public void setVideoOfCheating(String videoOfCheating) {
        this.videoOfCheating = videoOfCheating;
    }

    public String getUrlOfCheating() {
        return urlOfCheating;
    }

    public void setUrlOfCheating(String urlOfCheating) {
        this.urlOfCheating = urlOfCheating;
    }

    public String getHandler() {
        return handler;
    }

    public void setHandler(String handler) {
        this.handler = handler;
    }

    public String getHandleTime() {
        return handleTime;
    }

    public void setHandleTime(String handleTime) {
        this.handleTime = handleTime;
    }

    public String getHandleDesc() {
        return handleDesc;
    }

    public void setHandleDesc(String handleDesc) {
        this.handleDesc = handleDesc;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Long getLockSeconds() {
        return lockSeconds;
    }

    public void setLockSeconds(Long lockSeconds) {
        this.lockSeconds = lockSeconds;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }
}
